=== modified file 'bzrlib/counted_lock.py'
--- bzrlib/counted_lock.py	2008-04-24 07:22:53 +0000
+++ bzrlib/counted_lock.py	2008-06-05 07:59:29 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Canonical Ltd
+# Copyright (C) 2007, 2008 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -17,9 +17,8 @@
 """Counted lock class"""
 
 
-from bzrlib.errors import (
-    LockError,
-    ReadOnlyError,
+from bzrlib import (
+    errors,
     )
 
 
@@ -40,6 +39,10 @@
         self._lock_mode = None
         self._lock_count = 0
 
+    def __repr__(self):
+        return "%s(%r)" % (self.__class__.__name__,
+            self._real_lock)
+
     def break_lock(self):
         self._real_lock.break_lock()
         self._lock_mode = None
@@ -71,12 +74,12 @@
             self._real_lock.lock_write()
             self._lock_mode = 'w'
         elif self._lock_mode != 'w':
-            raise ReadOnlyError(self)
+            raise errors.ReadOnlyError(self)
         self._lock_count += 1
 
     def unlock(self):
         if self._lock_count == 0:
-            raise LockError("%s not locked" % (self,))
+            raise errors.LockNotHeld("%r not locked" % (self,))
         elif self._lock_count == 1:
             self._real_lock.unlock()
             self._lock_mode = None

=== modified file 'bzrlib/tests/test_counted_lock.py'
--- bzrlib/tests/test_counted_lock.py	2007-05-02 14:00:53 +0000
+++ bzrlib/tests/test_counted_lock.py	2008-06-05 07:59:29 +0000
@@ -1,4 +1,4 @@
-# Copyright (C) 2007 Canonical Ltd
+# Copyright (C) 2007, 2008 Canonical Ltd
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -19,7 +19,9 @@
 from bzrlib.counted_lock import CountedLock
 from bzrlib.errors import (
     LockError,
+    LockNotHeld,
     ReadOnlyError,
+    TokenMismatch,
     )
 from bzrlib.tests import TestCase
 
@@ -62,6 +64,13 @@
             raise LockError("%s is already locked in mode %r" %
                 (self, self._lock_mode))
 
+    def validate_token(self, token):
+        if token == 'token':
+            # already held by this caller
+            return 'token'
+        else:
+            raise TokenMismatch(token, 'token')
+
 
 class TestDummyLock(TestCase):
 
@@ -131,7 +140,7 @@
     def test_unlock_not_locked(self):
         real_lock = DummyLock()
         l = CountedLock(real_lock)
-        self.assertRaises(LockError, l.unlock)
+        self.assertRaises(LockNotHeld, l.unlock)
 
     def test_read_lock_while_write_locked(self):
         real_lock = DummyLock()

